Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/text.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJulius Härtl <jus@bitgrid.net>2022-08-19 00:43:01 +0300
committerJulius Härtl <jus@bitgrid.net>2022-08-19 00:57:29 +0300
commit158a6116ca7f06076cbceee8beb2eeee6e8417e6 (patch)
tree3382415f206d5deba388b6c20e3b467cbeb67f35
parentfe2f71cbed5b88b78514ce157647b483138a8cd8 (diff)
Rename components to Nc
Signed-off-by: Julius Härtl <jus@bitgrid.net>
-rw-r--r--src/components/Editor/AvatarWrapper.vue6
-rw-r--r--src/components/Editor/EditorOutline.vue8
-rw-r--r--src/components/Editor/SessionList.vue8
-rw-r--r--src/components/HelpModal.vue8
-rw-r--r--src/components/Menu/ActionImageUpload.vue20
-rw-r--r--src/components/Menu/ActionList.vue8
-rw-r--r--src/components/Menu/ActionSingle.vue10
-rw-r--r--src/components/Menu/EmojiPickerAction.vue16
-rw-r--r--src/components/Menu/MenuBar.vue2
-rw-r--r--src/components/PublicFilesEditor.vue8
-rw-r--r--src/nodes/Table/TableCellView.vue24
-rw-r--r--src/nodes/Table/TableHeaderView.vue24
-rw-r--r--src/nodes/Table/TableView.vue16
13 files changed, 79 insertions, 79 deletions
diff --git a/src/components/Editor/AvatarWrapper.vue b/src/components/Editor/AvatarWrapper.vue
index dee4fb33e..ab2ae46f6 100644
--- a/src/components/Editor/AvatarWrapper.vue
+++ b/src/components/Editor/AvatarWrapper.vue
@@ -1,6 +1,6 @@
<template>
<div class="avatar-wrapper" :style="sessionAvatarStyle">
- <Avatar v-if="session.userId"
+ <NcAvatar v-if="session.userId"
:user="session.userId ? session.userId : session.guestName"
:is-guest="session.userId === null"
:disable-menu="true"
@@ -14,11 +14,11 @@
</template>
<script>
-import Avatar from '@nextcloud/vue/dist/Components/Avatar.js'
+import NcAvatar from '@nextcloud/vue/dist/Components/NcAvatar.js'
export default {
name: 'AvatarWrapper',
components: {
- Avatar,
+ NcAvatar,
},
props: {
session: {
diff --git a/src/components/Editor/EditorOutline.vue b/src/components/Editor/EditorOutline.vue
index 1e8d41823..158c9db3a 100644
--- a/src/components/Editor/EditorOutline.vue
+++ b/src/components/Editor/EditorOutline.vue
@@ -2,11 +2,11 @@
<div data-text-el="editor-outline" class="editor--outline" :class="{ 'editor--outline-mobile': mobile }">
<header class="editor--outline__header">
<h2>{{ t('text', 'Outline') }}</h2>
- <Button type="tertiary" :aria-label="t('text', 'Close outline view')" @click="$outlineActions.toggle">
+ <NcButton type="tertiary" :aria-label="t('text', 'Close outline view')" @click="$outlineActions.toggle">
<template #icon>
<Close />
</template>
- </Button>
+ </NcButton>
</header>
<TableOfContents />
</div>
@@ -14,7 +14,7 @@
<script>
import debounce from 'debounce'
-import Button from '@nextcloud/vue/dist/Components/Button'
+import NcButton from '@nextcloud/vue/dist/Components/NcButton.js'
import TableOfContents from './TableOfContents.vue'
import { useOutlineStateMixin, useOutlineActions } from './Wrapper.provider.js'
import { Close } from './../icons.js'
@@ -24,7 +24,7 @@ export default {
name: 'EditorOutline',
components: {
Close,
- Button,
+ NcButton,
TableOfContents,
},
mixins: [useStore, useOutlineStateMixin, useOutlineActions],
diff --git a/src/components/Editor/SessionList.vue b/src/components/Editor/SessionList.vue
index c01db8542..d0a62c1ec 100644
--- a/src/components/Editor/SessionList.vue
+++ b/src/components/Editor/SessionList.vue
@@ -21,7 +21,7 @@
-->
<template>
- <Popover class="session-list" placement="bottom">
+ <NcPopover class="session-list" placement="bottom">
<button slot="trigger"
v-tooltip.bottom="label"
:title="label"
@@ -58,11 +58,11 @@
</p>
</div>
</template>
- </Popover>
+ </NcPopover>
</template>
<script>
-import Popover from '@nextcloud/vue/dist/Components/Popover.js'
+import NcPopover from '@nextcloud/vue/dist/Components/NcPopover.js'
import Tooltip from '@nextcloud/vue/dist/Directives/Tooltip.js'
import AvatarWrapper from './AvatarWrapper.vue'
import store from '../../mixins/store.js'
@@ -74,7 +74,7 @@ export default {
name: 'SessionList',
components: {
AvatarWrapper,
- Popover,
+ NcPopover,
},
directives: {
tooltip: Tooltip,
diff --git a/src/components/HelpModal.vue b/src/components/HelpModal.vue
index f801106ee..16900c7bf 100644
--- a/src/components/HelpModal.vue
+++ b/src/components/HelpModal.vue
@@ -1,5 +1,5 @@
<template>
- <Modal size="normal"
+ <NcModal size="normal"
:title="t('text', 'Formatting help')"
@close="$emit('close')">
<h2>{{ t('text', 'Formatting help') }}</h2>
@@ -154,18 +154,18 @@
</tr>
</tbody>
</table>
- </Modal>
+ </NcModal>
</template>
<script>
-import Modal from '@nextcloud/vue/dist/Components/Modal.js'
+import NcModal from '@nextcloud/vue/dist/Components/NcModal.js'
import Tooltip from '@nextcloud/vue/dist/Directives/Tooltip.js'
import isMobile from './../mixins/isMobile.js'
export default {
name: 'HelpModal',
components: {
- Modal,
+ NcModal,
},
directives: {
Tooltip,
diff --git a/src/components/Menu/ActionImageUpload.vue b/src/components/Menu/ActionImageUpload.vue
index 73373f077..153939f06 100644
--- a/src/components/Menu/ActionImageUpload.vue
+++ b/src/components/Menu/ActionImageUpload.vue
@@ -20,7 +20,7 @@
-
-->
<template>
- <Actions class="entry-action entry-action__image-upload"
+ <NcActions class="entry-action entry-action__image-upload"
:data-text-action-entry="actionEntry.key"
:title="actionEntry.label"
:aria-label="actionEntry.label"
@@ -32,7 +32,7 @@
:aria-label="actionEntry.label"
aria-haspopup />
</template>
- <ActionButton close-after-click
+ <NcActionButton close-after-click
:disabled="isUploadingImages"
:data-text-action-entry="`${actionEntry.key}-upload`"
@click="$callChooseLocalImage">
@@ -40,8 +40,8 @@
<Upload />
</template>
{{ t('text', 'Upload from computer') }}
- </ActionButton>
- <ActionButton v-if="!$isPublic"
+ </NcActionButton>
+ <NcActionButton v-if="!$isPublic"
close-after-click
:disabled="isUploadingImages"
:data-text-action-entry="`${actionEntry.key}-insert`"
@@ -50,13 +50,13 @@
<Folder />
</template>
{{ t('text', 'Insert from Files') }}
- </ActionButton>
- </Actions>
+ </NcActionButton>
+ </NcActions>
</template>
<script>
-import Actions from '@nextcloud/vue/dist/Components/Actions.js'
-import ActionButton from '@nextcloud/vue/dist/Components/ActionButton.js'
+import NcActions from '@nextcloud/vue/dist/Components/NcActions.js'
+import NcActionButton from '@nextcloud/vue/dist/Components/NcActionButton.js'
import { Loading, Folder, Upload } from '../icons.js'
import { useIsPublicMixin } from '../Editor.provider.js'
@@ -70,8 +70,8 @@ import {
export default {
name: 'ActionImageUpload',
components: {
- Actions,
- ActionButton,
+ NcActions,
+ NcActionButton,
Loading,
Folder,
Upload,
diff --git a/src/components/Menu/ActionList.vue b/src/components/Menu/ActionList.vue
index 2c71b3d60..88d170aaa 100644
--- a/src/components/Menu/ActionList.vue
+++ b/src/components/Menu/ActionList.vue
@@ -21,7 +21,7 @@
-->
<template>
- <Actions v-tooltip="tooltip"
+ <NcActions v-tooltip="tooltip"
class="entry-list-action entry-action"
role="menu"
v-bind="state"
@@ -37,11 +37,11 @@
is-item
:action-entry="child"
@trigged="onTrigger" />
- </Actions>
+ </NcActions>
</template>
<script>
-import Actions from '@nextcloud/vue/dist/Components/Actions.js'
+import NcActions from '@nextcloud/vue/dist/Components/NcActions.js'
import { BaseActionEntry } from './BaseActionEntry.js'
import ActionSingle from './ActionSingle.vue'
import { getIsActive } from './utils.js'
@@ -50,7 +50,7 @@ import useStore from '../../mixins/store.js'
export default {
name: 'ActionList',
- components: { Actions, ActionSingle },
+ components: { NcActions, ActionSingle },
extends: BaseActionEntry,
mixins: [useStore, useOutlineStateMixin],
computed: {
diff --git a/src/components/Menu/EmojiPickerAction.vue b/src/components/Menu/EmojiPickerAction.vue
index 8218194e8..f2ce30fcb 100644
--- a/src/components/Menu/EmojiPickerAction.vue
+++ b/src/components/Menu/EmojiPickerAction.vue
@@ -20,10 +20,10 @@
-
-->
<template>
- <EmojiPicker class="entry-action entry-action__emoji"
+ <NcEmojiPicker class="entry-action entry-action__emoji"
:data-text-action-entry="actionEntry.key"
@selectData="addEmoji">
- <ButtonVue v-tooltip="actionEntry.label"
+ <NcButton v-tooltip="actionEntry.label"
class="entry-action__button"
role="menu"
:title="actionEntry.label"
@@ -32,20 +32,20 @@
<template #icon>
<component :is="icon" />
</template>
- </ButtonVue>
- </EmojiPicker>
+ </NcButton>
+ </NcEmojiPicker>
</template>
<script>
import { BaseActionEntry } from './BaseActionEntry.js'
-import EmojiPicker from '@nextcloud/vue/dist/Components/EmojiPicker.js'
-import ButtonVue from '@nextcloud/vue/dist/Components/ButtonVue.js'
+import NcEmojiPicker from '@nextcloud/vue/dist/Components/NcEmojiPicker.js'
+import NcButton from '@nextcloud/vue/dist/Components/NcButton.js'
export default {
name: 'EmojiPickerAction',
components: {
- EmojiPicker,
- ButtonVue,
+ NcEmojiPicker,
+ NcButton,
},
extends: BaseActionEntry,
methods: {
diff --git a/src/components/Menu/MenuBar.vue b/src/components/Menu/MenuBar.vue
index a9907af71..ba589f1fe 100644
--- a/src/components/Menu/MenuBar.vue
+++ b/src/components/Menu/MenuBar.vue
@@ -137,7 +137,7 @@ export default {
remainAction() {
return {
key: 'remain',
- label: this.t('text', 'Remaining Actions'),
+ label: this.t('text', 'Remaining actions'),
icon: DotsHorizontal,
children: this.hiddenEntries,
}
diff --git a/src/components/PublicFilesEditor.vue b/src/components/PublicFilesEditor.vue
index 77ea505c6..ddf29b220 100644
--- a/src/components/PublicFilesEditor.vue
+++ b/src/components/PublicFilesEditor.vue
@@ -21,22 +21,22 @@
-->
<template>
- <Modal v-if="active" :title="fileName" @close="close">
+ <NcModal v-if="active" :title="fileName" @close="close">
<Editor :file-id="fileId"
:relative-path="relativePath"
:active="active"
:share-token="shareToken"
:mime="mimeType" />
- </Modal>
+ </NcModal>
</template>
<script>
-import Modal from '@nextcloud/vue/dist/Components/Modal.js'
+import NcModal from '@nextcloud/vue/dist/Components/NcModal.js'
export default {
name: 'PublicFilesEditor',
components: {
- Modal,
+ NcModal,
Editor: () => import(/* webpackChunkName: "editor" */'./Editor.vue'),
},
props: {
diff --git a/src/nodes/Table/TableCellView.vue b/src/nodes/Table/TableCellView.vue
index dc3b2f6aa..e12288a4e 100644
--- a/src/nodes/Table/TableCellView.vue
+++ b/src/nodes/Table/TableCellView.vue
@@ -24,48 +24,48 @@
<NodeViewWrapper data-text-el="table-cell" as="td">
<div class="container">
<NodeViewContent class="content" />
- <Actions v-if="editor.isEditable"
+ <NcActions v-if="editor.isEditable"
data-text-table-actions="row">
- <ActionButton data-text-table-action="add-row-before"
+ <NcActionButton data-text-table-action="add-row-before"
close-after-click
@click="addRowBefore">
<template #icon>
<TableAddRowBefore />
</template>
{{ t('text', 'Add row before') }}
- </ActionButton>
- <ActionButton data-text-table-action="add-row-after"
+ </NcActionButton>
+ <NcActionButton data-text-table-action="add-row-after"
close-after-click
@click="addRowAfter">
<template #icon>
<TableAddRowAfter />
</template>
{{ t('text', 'Add row after') }}
- </ActionButton>
- <ActionButton data-text-table-action="remove-row"
+ </NcActionButton>
+ <NcActionButton data-text-table-action="remove-row"
close-after-click
@click="deleteRow">
<template #icon>
<Delete />
</template>
{{ t('text', 'Delete this row') }}
- </ActionButton>
- </Actions>
+ </NcActionButton>
+ </NcActions>
</div>
</NodeViewWrapper>
</template>
<script>
import { NodeViewWrapper, NodeViewContent } from '@tiptap/vue-2'
-import Actions from '@nextcloud/vue/dist/Components/Actions.js'
-import ActionButton from '@nextcloud/vue/dist/Components/ActionButton.js'
+import NcActions from '@nextcloud/vue/dist/Components/NcActions.js'
+import NcActionButton from '@nextcloud/vue/dist/Components/NcActionButton.js'
import { TableAddRowBefore, TableAddRowAfter, Delete } from '../../components/icons.js'
export default {
name: 'TableCellView',
components: {
- ActionButton,
- Actions,
+ NcActionButton,
+ NcActions,
NodeViewWrapper,
NodeViewContent,
TableAddRowBefore,
diff --git a/src/nodes/Table/TableHeaderView.vue b/src/nodes/Table/TableHeaderView.vue
index e08f7902d..b6b6a3d0c 100644
--- a/src/nodes/Table/TableHeaderView.vue
+++ b/src/nodes/Table/TableHeaderView.vue
@@ -24,48 +24,48 @@
<NodeViewWrapper data-text-el="table-header" as="th">
<div>
<NodeViewContent class="content" />
- <Actions v-if="editor.isEditable"
+ <NcActions v-if="editor.isEditable"
data-text-table-actions="header">
- <ActionButton data-text-table-action="add-column-before"
+ <NcActionButton data-text-table-action="add-column-before"
close-after-click
@click="addColumnBefore">
<template #icon>
<TableAddColumnBefore />
</template>
{{ t('text', 'Add column before') }}
- </ActionButton>
- <ActionButton data-text-table-action="add-column-after"
+ </NcActionButton>
+ <NcActionButton data-text-table-action="add-column-after"
close-after-click
@click="addColumnAfter">
<template #icon>
<TableAddColumnAfter />
</template>
{{ t('text', 'Add column after') }}
- </ActionButton>
- <ActionButton data-text-table-action="remove-column"
+ </NcActionButton>
+ <NcActionButton data-text-table-action="remove-column"
close-after-click
@click="deleteColumn">
<template #icon>
<Delete />
</template>
{{ t('text', 'Delete this column') }}
- </ActionButton>
- </Actions>
+ </NcActionButton>
+ </NcActions>
</div>
</NodeViewWrapper>
</template>
<script>
import { NodeViewWrapper, NodeViewContent } from '@tiptap/vue-2'
-import Actions from '@nextcloud/vue/dist/Components/Actions.js'
-import ActionButton from '@nextcloud/vue/dist/Components/ActionButton.js'
+import NcActions from '@nextcloud/vue/dist/Components/NcActions.js'
+import NcActionButton from '@nextcloud/vue/dist/Components/NcActionButton.js'
import { Delete, TableAddColumnBefore, TableAddColumnAfter } from '../../components/icons.js'
export default {
name: 'TableHeaderView',
components: {
- ActionButton,
- Actions,
+ NcActionButton,
+ NcActions,
NodeViewWrapper,
NodeViewContent,
Delete,
diff --git a/src/nodes/Table/TableView.vue b/src/nodes/Table/TableView.vue
index 505a644a9..56e6f1c74 100644
--- a/src/nodes/Table/TableView.vue
+++ b/src/nodes/Table/TableView.vue
@@ -23,37 +23,37 @@
<template>
<NodeViewWrapper data-text-el="table-view" class="table-wrapper">
<NodeViewContent class="content" as="table" />
- <Actions v-if="editor.isEditable"
+ <NcActions v-if="editor.isEditable"
force-menu
data-text-table-actions="settings"
class="table-settings">
<template #icon>
<TableSettings />
</template>
- <ActionButton data-text-table-action="delete"
+ <NcActionButton data-text-table-action="delete"
close-after-click
@click="deleteNode">
<template #icon>
<Delete />
</template>
{{ t('text', 'Delete this table') }}
- </ActionButton>
- </Actions>
+ </NcActionButton>
+ </NcActions>
<div class="clearfix" />
</NodeViewWrapper>
</template>
<script>
import { NodeViewWrapper, NodeViewContent } from '@tiptap/vue-2'
-import Actions from '@nextcloud/vue/dist/Components/Actions.js'
-import ActionButton from '@nextcloud/vue/dist/Components/ActionButton.js'
+import NcActions from '@nextcloud/vue/dist/Components/NcActions.js'
+import NcActionButton from '@nextcloud/vue/dist/Components/NcActionButton.js'
import { TableSettings, Delete } from '../../components/icons.js'
export default {
name: 'TableView',
components: {
- ActionButton,
- Actions,
+ NcActionButton,
+ NcActions,
NodeViewWrapper,
NodeViewContent,
TableSettings,
diff --git a/src/components/Menu/ActionSingle.vue b/src/components/Menu/ActionSingle.vue
index c5b96308a..dc3c21ee9 100644
--- a/src/components/Menu/ActionSingle.vue
+++ b/src/components/Menu/ActionSingle.vue
@@ -21,8 +21,8 @@
-->
<script>
-import ButtonVue from '@nextcloud/vue/dist/Components/ButtonVue.js'
-import ActionButton from '@nextcloud/vue/dist/Components/ActionButton.js'
+import NcButton from '@nextcloud/vue/dist/Components/NcButton.js'
+import NcActionButton from '@nextcloud/vue/dist/Components/NcActionButton.js'
import { BaseActionEntry } from './BaseActionEntry.js'
export default {
@@ -36,11 +36,11 @@ export default {
},
computed: {
component() {
// Button and ActionButton shares styles and behaviours
// to keep it simple, this component handle the small differences
return this.isItem
- ? ActionButton
- : ButtonVue
+ ? NcActionButton
+ : NcButton
},
bindState() {
const { keyshortcuts } = this
@@ -36,11 +36,11 @@ export default {
computed: {
component() {
- // Button and ActionButton shares styles and behaviours
+ // Button and NcActionButton shares styles and behaviours
// to keep it simple, this component handle the small differences
return this.isItem